跳到主要内容

AcceptedAlert

结构体 AcceptedAlert 

pub struct AcceptedAlert(/* private fields */);
展开描述

Represents 一个 TLS alert resulting 从 handling the client’s ClientHello message.

When Acceptor::accept() returns an error, it yields an AcceptedAlert such that the application can communicate failure 到 the client via AcceptedAlert::write()

实现

Source

impl AcceptedAlert

pub fn write(&mut self, wr: &mut dyn Write) -> Result<usize, Error>

Send the alert 到 the client.

To account 用于 short writes 此函数 should be called repeatedly until it returns Ok(0) 或 an error.

pub fn write_all(&mut self, wr: &mut dyn Write) -> Result<(), Error>

Send the alert 到 the client.

This function will invoke the writer until 缓冲区 is empty.

Trait 实现

Source

impl Debug for AcceptedAlert

Source

fn fmt(&self, f: &mut Formatter<'_>) -> Result

使用给定的格式化器格式化此值。 更多信息
Source

impl From<ConnectionCommon<ServerConnectionData>> for AcceptedAlert

Source

fn from(conn: ConnectionCommon<ServerConnectionData>) -> Self

从输入类型转换为此类型。

自动 Trait 实现

Blanket 实现

Source

impl<T> Any for T
where T: 'static + ?Sized,

Source

fn type_id(&self) -> TypeId

Gets the TypeId of self. 更多信息
Source

impl<T> Borrow<T> for T
where T: ?Sized,

Source

fn borrow(&self) -> &T

Immutably borrows 从 an owned value. 更多信息
Source

impl<T> BorrowMut<T> for T
where T: ?Sized,

Source

fn borrow_mut(&mut self) -> &mut T

Mutably borrows 从 an owned value. 更多信息
Source

impl<T> From<T> for T

Source

fn from(t: T) -> T

原样返回传入的参数。

Source

impl<T, U> Into<U> for T
where U: From<T>,

Source

fn into(self) -> U

Calls U::从(self)

That is, this conversion is whatever the implementation of From<T> 用于 U 的实现方式。

Source

impl<T, U> TryFrom<U> for T
where U: Into<T>,

Source

type Error = Infallible

转换出错时返回的类型。
Source

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

执行转换。
Source

impl<T, U> TryInto<U> for T
where U: TryFrom<T>,

Source

type Error = <U as TryFrom<T>>::Error

转换出错时返回的类型。
Source

fn try_into(self) -> Result<U, <U as TryFrom<T>>::Error>

执行转换。