pub struct ReadEarlyData<'a> { /* private fields */ }展开描述
允许在恢复的 TLS 1.3 连接中读取早期数据。
“Early data” 也 known as “0-RTT data”。
此结构体实现了 std::io::Read。
Trait 实现
Sourceimpl Read for ReadEarlyData<'_>
impl Read for ReadEarlyData<'_>
Sourcefn read(&mut self, buf: &mut [u8]) -> Result<usize>
fn read(&mut self, buf: &mut [u8]) -> Result<usize>
Pull some bytes from this source into the specified buffer, returning
how many bytes were read. 更多信息
1.36.0 · Sourcefn read_vectored(&mut self, bufs: &mut [IoSliceMut<'_>]) -> Result<usize, Error>
fn read_vectored(&mut self, bufs: &mut [IoSliceMut<'_>]) -> Result<usize, Error>
Like
read, except that it reads into 一个 slice of buffers. 更多信息Sourcefn is_read_vectored(&self) -> bool
fn is_read_vectored(&self) -> bool
🔬This is a nightly-only experimental API. (
can_vector)1.0.0 · Sourcefn read_to_end(&mut self, buf: &mut Vec<u8>) -> Result<usize, Error>
fn read_to_end(&mut self, buf: &mut Vec<u8>) -> Result<usize, Error>
Reads all bytes until EOF in this source, placing them into
buf. 更多信息1.0.0 · Sourcefn read_to_string(&mut self, buf: &mut String) -> Result<usize, Error>
fn read_to_string(&mut self, buf: &mut String) -> Result<usize, Error>
Reads all bytes until EOF in this source, appending them 到
buf. 更多信息1.6.0 · Sourcefn read_exact(&mut self, buf: &mut [u8]) -> Result<(), Error>
fn read_exact(&mut self, buf: &mut [u8]) -> Result<(), Error>
Reads the exact number of bytes required 到 fill
buf. 更多信息Sourcefn read_buf(&mut self, buf: BorrowedCursor<'_>) -> Result<(), Error>
fn read_buf(&mut self, buf: BorrowedCursor<'_>) -> Result<(), Error>
🔬This is a nightly-only experimental API. (
read_buf)Pull some bytes 从 this source into the specified 缓冲区. 更多信息
Sourcefn read_buf_exact(&mut self, cursor: BorrowedCursor<'_>) -> Result<(), Error>
fn read_buf_exact(&mut self, cursor: BorrowedCursor<'_>) -> Result<(), Error>
🔬This is a nightly-only experimental API. (
read_buf)Reads the exact number of bytes required 到 fill
cursor. 更多信息1.0.0 · Sourcefn by_ref(&mut self) -> &mut Selfwhere
Self: Sized,
fn by_ref(&mut self) -> &mut Selfwhere
Self: Sized,
Creates 一个 “by reference” adapter 用于 this instance of
Read. 更多信息1.0.0 · Sourcefn chain<R>(self, next: R) -> Chain<Self, R>
fn chain<R>(self, next: R) -> Chain<Self, R>
Creates an adapter which will chain this stream with another. 更多信息
自动 Trait 实现
impl<'a> Freeze for ReadEarlyData<'a>
impl<'a> RefUnwindSafe for ReadEarlyData<'a>
impl<'a> Send for ReadEarlyData<'a>
impl<'a> Sync for ReadEarlyData<'a>
impl<'a> Unpin for ReadEarlyData<'a>
impl<'a> UnsafeUnpin for ReadEarlyData<'a>
impl<'a> !UnwindSafe for ReadEarlyData<'a>
Blanket 实现
Sourceimpl<T> BorrowMut<T> for Twhere
T: ?Sized,
impl<T> BorrowMut<T> for Twhere
T: ?Sized,
Sourcefn borrow_mut(&mut self) -> &mut T
fn borrow_mut(&mut self) -> &mut T
Mutably borrows 从 an owned value. 更多信息